@@ -1,8 +1,8 @@
 """
-kalapy.admin.base
-~~~~~~~~~~~~~~~~~
+kalapy.admin
+~~~~~~~~~~~~
 
-This module implemented api to write command line admin scripts.
+This module implements script api to write command line admin scripts.
 
 :copyright: (c) 2010 Amit Mendapara.
 :license: BSD, see LINCESE for more details.
@@ -11,6 +11,12 @@ import re, os, sys, types, getopt
 
 from werkzeug import find_modules, import_string
 
+try:
+    from pygments.console import ansiformat
+except ImportError:
+    def ansiformat(attr, s):
+        return s
+
 from kalapy import get_version
 
 
@@ -242,7 +248,11 @@ class Command(object):
     def error(self, msg):
         """Print the given error message and exit.
         """
-        print msg
+        if not isinstance(msg, basestring):
+            msg = '%s' % msg
+        if not msg.startswith('Error:'):
+            msg = 'Error: %s' % msg
+        print ansiformat('*red*', msg)
         sys.exit(1)
 
     def print_help(self):
@@ -360,7 +370,7 @@ class Main(object):
         print
         print "available commands:"
         print
-        for name in REGISTRY:
+        for name in sorted(REGISTRY):
             print "  %s" % name
         print
         print 'use "%s help <command>" for more details on a command' % self.prog
@@ -397,10 +407,9 @@ class Main(object):
 
         try:
             command = REGISTRY[cmd]
-        except:
-            raise CommandError('no such command %r' % cmd)
-
-        command().run(args)
+            command().run(args)
+        except KeyError:
+            print ansiformat('*red*', 'Error: No such command %r.' % cmd)
 
 
 def setup_environment(settings_mod):
@@ -408,7 +417,8 @@ def setup_environment(settings_mod):
     It will update the configuration settings and load the project.
     """
     from kalapy.conf import settings
-    settings.update(settings_mod)
+    project_dir = os.path.dirname(os.path.abspath(settings_mod.__file__))
+    settings.update(settings_mod, project_dir=project_dir)
 
 
 def execute_command(args=None, settings_mod=None):
