@@ -13,7 +13,6 @@ import sys
 from kalapy import db
 from kalapy.admin import ActionCommand
 from kalapy.conf import settings
-from kalapy.conf.loader import loader
 from kalapy.db.engines import database
 
 
@@ -53,13 +52,17 @@ class DBCommand(ActionCommand):
         if settings.DATABASE_ENGINE == "dummy":
             raise self.error("DATABASE_ENGINE is not configured.")
 
-        database.connect()
         try:
-            # load packages
-            loader.load()
-            super(DBCommand, self).execute(options, args)
-        finally:
-            database.close()
+            database.connect()
+            try:
+                # Initialize the object pool
+                from kalapy.core.pool import pool
+                pool.load()
+                super(DBCommand, self).execute(options, args)
+            finally:
+                database.close()
+        except db.DatabaseError, e:
+            self.error(e)
 
     def get_models(self, *packages):
         """Similar to `db.get_models` but returns a tuple, (list of models,
@@ -71,7 +74,10 @@ class DBCommand(ActionCommand):
         :param packages: sequence of package names
         :returns: a tuple
         """
-        models = db.get_models(*packages)
+        try:
+            models = db.get_models(*packages)
+        except Exception, e:
+            self.error(e)
 
         result = []
         pending = []
@@ -92,7 +98,7 @@ class DBCommand(ActionCommand):
         return result, pending
 
     def action_info(self, options, packages):
-        """Show the table schema for the given packages
+        """Show the table schema for the given packages.
         """
         if not packages:
             raise self.error('no package name provided.')
@@ -171,4 +177,3 @@ Are you sure about this action? (y/N): """ % settings.DATABASE_NAME)
             raise
         else:
             database.commit()
-
